package org.apidesign.apifest08.currency;

import java.util.*;

/**
 * Exception thrown in cases that a CurrencyConverter is unable ensure requested accuracy of conversion.
 * Such situation may occur in cases that the client is not on-line, or the exchange rates are older than
 * requested etc. This exception is defined as RuntimeException to enable simple usage in simple applications,
 * but enable other applications to be informed about possible problems and prevent them from using
 * inaccurate data.
 */
public final class CurrencyConversionException extends RuntimeException {

	private final Currency from;
	private final Currency to;

	CurrencyConversionException(Currency from, Currency to) {
		this(from, to, (Throwable) null);
	}

	CurrencyConversionException(Currency from, Currency to, Throwable throwable) {
		this(from, to, String.format("Failed to convert curency from %1$s to %2$s", from, to), throwable);
	}

	CurrencyConversionException(Currency from, Currency to, String message) {
		this(from, to, message, null);
	}

	CurrencyConversionException(Currency from, Currency to, String message, Throwable throwable) {
		super(message, throwable);
		this.from = from;
		this.to = to;
	}

	public Currency getFromCurrency() {
		return from;
	}

	public Currency getToCurrency() {
		return to;
	}
}
